@@ -12,11 +12,35 @@ from cloudmesh.common.util import readfile
 
 class Host(object):
 
+    @staticmethod
+    def get_hostnames(names):
+        """
+        Given a list of host names it identifies if they have numbers in them. If so, they are assumed workers.
+        If not, it is a manager. There can only be one manager.
+
+        @param names: list of names
+        @type names: str
+        @return: manager, worker as list
+        @rtype: tuple
+        """
+        manager = None
+        workers = []
+        for name in names:
+            if any(map(str.isdigit, name)):
+                workers.append(name)
+            else:
+                manager = name
+
+        if len(workers) == 0:
+            workers = None
+
+        return manager, workers
+
     @staticmethod
     def config(hosts=None,
                ips=None,
                username=None,
-               key="~/.ssh/id_rsa.pub"):
+               key="~/.ssh/id_rsa"):
 
         if type(hosts) != list:
             _hosts = Parameter.expand(hosts)
@@ -27,7 +51,7 @@ class Host(object):
                 raise ValueError("Number of hosts and ips mismatch")
 
         result = ""
-        for i in range(0,len(_hosts)):
+        for i in range(0, len(_hosts)):
 
             host = _hosts[i]
 
@@ -54,7 +78,6 @@ class Host(object):
             result += data
         return result
 
-
     @staticmethod
     def _run(args):
         """
@@ -103,7 +126,6 @@ class Host(object):
             returncode = result.returncode
             stdout = result.stdout
 
-
         data = {
             'host': args.get("host"),
             'command': args.get("command"),
@@ -162,11 +184,11 @@ class Host(object):
     def ssh(hosts=None,
             command=None,
             username=None,
-            key="~/.ssh/id_rsa.pub",
+            key="~/.ssh/id_rsa",
             processors=3,
             dryrun=False,  # notused
             executor=None,
-            verbose=False, # not used
+            verbose=False,  # not used
             **kwargs):
         #
         # BUG: this code has a bug and does not deal with different
@@ -206,7 +228,7 @@ class Host(object):
             source=None,
             destination=None,
             username=None,
-            key="~/.ssh/id_rsa.pub",
+            key="~/.ssh/id_rsa",
             shell=False,
             processors=3,
             dryrun=False,
@@ -232,8 +254,11 @@ class Host(object):
                    source,
                    "{host}:{destination}"]
 
+        execute = f"cp {source} {destination}"
+
         result = Host.run(hosts=hosts,
                           command=command,
+                          execute=execute,
                           destination=destination,
                           shell=False)
 
@@ -242,7 +267,7 @@ class Host(object):
     @staticmethod
     def check(hosts=None,
               username=None,
-              key="~/.ssh/id_rsa.pub",
+              key="~/.ssh/id_rsa",
               processors=3):
         #
         # BUG: this code has a bug and does not deal with different
@@ -266,7 +291,7 @@ class Host(object):
 
         return result
 
-    # noinspection PyBroadException
+    # noinspection PyBroadException,PyPep8
     @staticmethod
     def _ping(args):
         """
@@ -388,7 +413,7 @@ class Host(object):
                                command='cat .ssh/id_rsa.pub',
                                username=username,
                                verbose=False)
-        #results_authorized = Host.ssh(hosts=names,
+        # results_authorized = Host.ssh(hosts=names,
         #                              command='cat .ssh/id_rsa.pub',
         #                              username=username,
         #                              verbose=False)
@@ -404,12 +429,11 @@ class Host(object):
             'date': DateTime.now()
         }
 
-        if results_key is None: # and results_authorized is None:
+        if results_key is None:  # and results_authorized is None:
             return ""
 
-        # geting the output and also removing duplicates
-        output = [localkey['stdout']] + \
-                 list(set([element["stdout"] for element in results_key]))
+        # getting the output and also removing duplicates
+        output = [localkey['stdout']] + list(set([element["stdout"] for element in results_key]))
 
         output = '\n'.join(output) + "\n"
 
